# Debugging Reinforcement Learning

Objectives:

* Show how cherry helps you catch bugs with defensive programming,
* Show how to use the VisdomLogger and the Record wrapper,
* Explain how to use the debug mode, (post-mortem, logger, warning from functions)
* Maybe showcase all of the above with an example that seems right but doesn't work,
* Provide some tips and tricks on debugging.
